@@ -3,8 +3,11 @@ from .Database import DatabaseManager
 from .Music import *
 from .Paginator import PageManager, generate_embeds
 from .ReactionRoles import ReactionManager
+from .Economy import EconomyManager, EconomyAccount
+from .Imaging import ImageManager
+from .InviteTracker import InviteTracker
 
 __title__ = "discordSuperUtils"
-__version__ = "0.0.1"
+__version__ = "0.1.3"
 __author__ = "Koyashie07 & Adam7100"
 __license__ = "MIT"
\ No newline at end of file
